<?php

/*

Timetable, functions for managing deadlines
Copyright (C) 2004 Ari Takku

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/


// functions that sorts deadlines

function hasBeenDeadlineSort($a, $b)
{
  $sep = $GLOBALS['DEADLINE_SEPARATOR'];


  $v1 = $a["deadline"];
  $v2 = $b["deadline"];


  if ($v1 < $v2)
    return 1;
  else if ($v1 > $v2)
    return -1;
  else
    return 0;
}


function comingDeadlineSort($a, $b)
{
  $sep = $GLOBALS['DEADLINE_SEPARATOR'];


  $v1 = $a["deadline"];
  $v2 = $b["deadline"];


  if ($v1 < $v2)
    return -1;
  else if ($v1 > $v2)
    return 1;
  else
    return 0;
}

// returns an array that has two arrays within: 

// first one has coming deadlines:
// [0] => array("deadline" => ..., "description" => ..., "days_left" => ...), 
// [1] => array("deadline" => ..., "description" => ..., "days_left" => ...), 

// second the deadlines that have already wooshed by 

function fetchDeadlineData()
{
  $data = file($GLOBALS['FILE_DEADLINE']);
  
  $today = strtotime(date("Y-m-d H:i:s"));

  $deadlines = array();
  $has_beens = array();
      
  for ($i = 0; $i < count($data); $i++)
  {
    $tmp = explode($GLOBALS['DEADLINE_SEPARATOR'], $data[$i]);

    $deadline = strtotime( $tmp[0] );
    $description = trim($tmp[1]);

    $days_left = ceil(($deadline - $today)/86400);

    $tmp_arr = array("deadline" => $deadline,
		     "description" => $description, 
		     "days_left" => $days_left
		     );



    // deadlines that have wooshed by 
    if ($deadline < $today)
    {      
      array_push($has_beens, $tmp_arr);
    }
    // coming deadlines
    else
    {
      array_push($deadlines, $tmp_arr);
    }
  }

  return array($deadlines, $has_beens);
}

function printTableFromDeadlines($deadlines, $modify, $title, $coming, $id_src)
{
  $table_title = $coming ? "coming" : "hasbeen";

  print('
<table class="'.$table_title.'" cellspacing="0" cellpadding="0">
<tr>
   <th class="dl_title" colspan="4">'.$title.'</th>
</tr>
<tr>
   <th>'.localize("DL_DATE").'</th>
   <th>'.localize("DL_TIME").'</th>
   <th>'.localize("DL_DESCRIPTION").'</th>
   <th>'.localize("DL_DAYS_LEFT").'</th>
</tr>
');
  
  $now = true;
  $counter = $id_src;
  foreach( $deadlines as $c )
  {
    $counter++;
    $class = $now ? "" : " class=\"emphasize\"";
    
    print("\n<tr$class>\n");
    $pvm = date("d.m.Y H:i:s",  $c['deadline']);
    //    $pvm = trim($c['deadline']);
    $desc = trim($c['description']);
    $days_left = trim($c['days_left']);

    if ( $pvm == "" and $desc == "" and $days_left == "") 
    { 
      continue; 
    }

    $time_arr = explode(" ", $pvm);
    $date = explode(".", $time_arr[0]);
    $clock = explode(":", $time_arr[1]);
    


    if ( $modify )
    {
      print("<td class=\"pvm\">\n");
      printSelectWidget("dl_days_$counter", 1, 32, $date[0]);
      print(".");
      printSelectWidget("dl_months_$counter", 1, 13, $date[1]);
      print(".");
      printSelectWidget("dl_years_$counter",date("Y"),date("Y")+2, $date[2]);  
      print("\n</td>\n");
      
      print("<td class=\"clock\">\n");
      printSelectWidget("dl_clock_tt_$counter", 0, 24, "".$clock[0]);
      print ":";
      printSelectWidget("dl_clock_mm_$counter", 0, 60, "".$clock[1]);
      print("\n</td>\n");

print("
<td class=\"desc\">
   <input type=\"text\" name=\"dl_desc_$counter\" value=\"$desc\" />
</td>
<td class=\"days_left\">
   $days_left
</td>
");
    }
    else
    {
      print("
<td class=\"pvm\">$time_arr[0]</td>
<td class=\"clock\">$time_arr[1]</td>
<td class=\"desc\">$desc</td>
<td class=\"days_left\">$days_left</td>
");
    }

    print("\n</tr>\n");

    $now = !$now;
  }

  print("</table>\n");

}

function printDeadlines($modify)
{

  $data = fetchDeadlineData();

  $toCome = $data[0];
  $hasBeen = $data[1];

  // sorting
  usort($toCome, "comingDeadlineSort");
  usort($hasBeen, "hasBeenDeadlineSort");


  if ( $modify )
  {
    print('<form action="deadline_formhandler.php" method="post">'."\n");
  }
  
  print('<div class="dl">'."\n");


  $id_src = 0;
  
  // coming deadlines
  printTableFromDeadlines($toCome, $modify, 
			  localize("DL_COMING"), true, $id_src);


  $id_src = count( $toCome );

  // gone
  printTableFromDeadlines($hasBeen, $modify, 
			  localize("DL_OLD"), false, $id_src);

  if($modify)
  {
    print('<div class="tip">'.localize("DL_TIP").'</div>');
  }
  print ("</div>\n");

  if ( $modify )
  {
    print("<p>\n".'<input type="submit" name="deadline_save" value="'.
	  localize("DL_SAVE").'" />'."\n</p>\n");
    print('</form>'."\n");
  }
}


?>
