<?php

/*

Timetable, functions for managing the timetable
Copyright (C) 2004 Ari Takku

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/


// returns the timetable data in an array of arrays, so that
// one array contains title and class for one hour
function fetchTimetableData()
{
  $data = file($GLOBALS['FILE_TIMETABLE']);

  $arr = array();

  foreach ( $data as $d )
  {
    $tmpArr = explode($GLOBALS['SEPARATOR_ONE'], $d);
    $tmpArrA = explode($GLOBALS['SEPARATOR_TWO'], $tmpArr[0]);
    $tmpArrB = explode($GLOBALS['SEPARATOR_TWO'], $tmpArr[1]);
    
    $arrayThatHasValues = 
      array( trim($tmpArrA[0]), trim($tmpArrA[1]), 
	     trim($tmpArrB[0]), trim($tmpArrB[1]) );
    
    array_push($arr, $arrayThatHasValues);
  }
  
  return $arr;
}


// builds an input element for the timetable modify form
function buildTimetableWidget($name, $value, $class = "")
{
  $class = ($class != "") ? " class=\"".$class."\" " : "";
   return 
     '<input '.$class.' type="text" size="10" name="'.
     $name.'" value="'.$value.'"/>';  
}

// Produces the structure for one cell in timetable modify table
// number is the number of the cell
// arrOfValues must contain four values: 
// 0 => topleft value, 1 => topright value, 
// 2 => bottomleft value, 3 => bottomright value
function buildOneCell($number, $arrOfValues, $modify = false)
{

  $topl = $modify ? 
    buildTimetableWidget($number."_topleft", 
			 $arrOfValues[0], "")  : $arrOfValues[0];
  $topr = $modify ? 
    buildTimetableWidget($number."_topright", 
			 $arrOfValues[1], "right") : $arrOfValues[1];
  $btml = $modify ? 
    buildTimetableWidget($number."_bottomleft", 
			 $arrOfValues[2], "") : $arrOfValues[2];
  $btmr = $modify ? 
    buildTimetableWidget($number."_bottomright", 
			 $arrOfValues[3], "right") : $arrOfValues[3];

  if ( $topl == "" ) { $topl = "&nbsp;"; }
  if ( $topr == "" ) { $topr = "&nbsp;"; }
  if ( $btml == "" ) { $btml = "&nbsp;"; }
  if ( $btmr == "" ) { $btmr = "&nbsp;"; }

  print('<table cellpadding="0" cellspacing="0">
   <tr>
      <td>'.$topl.'</td>
      <td class="right">'.$topr.'</td>
   </tr>
   <tr>
      <td>'.$btml.'</td>
      <td class="right">'.trim($btmr).'</td>
   </tr>
</table>
');

}


function printTimetable($modify = false)
{
  $data = fetchTimetableData();
  if ($modify)
  {
    print('<form action="timetable_formhandler.php" method="post">'."\n");
  }

  print('
<div class="tt">
<table cellspacing="0" cellpadding="0" class="timetable">
<tr>   
   <th class="time">'.localize("TIME").'</th>
');

  // days of week to the topmost row
  foreach ($GLOBALS['DAYS_OF_WORKING_WEEK'] as $day)
  {
    print("   <th>$day</th>\n");
  }

  print("</tr>\n");


  $times = buildTimeArray();

  $counter = 0;
  for ( $i = 0; $i < count($times); $i++ )
  {
    // clock time
    print("<tr>\n");
    print("<td class=\"time\">".$times[$i]."</td>\n");
  
    $tmpForDay = array();  
    
    // all days
    for ( $j = 0; $j < count($GLOBALS['DAYS_OF_WORKING_WEEK']); $j++ )
    {
      if ( count($data) <= $counter )
      {
	$arrayThatHasValues = array("", "", "", "");
      }
      else
      {
	$arrayThatHasValues = $data[$counter];
      }

      print("\n<td>\n");
      buildOneCell($counter, $arrayThatHasValues, $modify);
      print("\n</td>\n");

      $counter++;
    }

    print("</tr>\n");  
  }


  print('</table>'."\n</div>\n");

  if ($modify)
  {
    print('<p>
<input type="submit" name="timetable_save" value="'.localize("TT_SAVE").'" />
</p>
</form>
');
  }

}


?>
